@@ -17,8 +17,9 @@ class ImConfig(object):
         return os.path.exists('/usr/bin/im-config')
 
     def getAvailableInputMethods(self):
-        inputMethods = subprocess.check_output(['im-config', '-l']).decode().split()
-        return sorted(inputMethods)
+        inputMethods = sorted(subprocess.check_output(['im-config', '-l']).decode().split())
+        inputMethods.append('none')
+        return inputMethods
 
     def getCurrentInputMethod(self):
         (systemConfig, userConfig, autoConfig) = \
@@ -36,12 +37,18 @@ class ImConfig(object):
         except locale.Error:
             return None
         desktop = os.environ.get('XDG_CURRENT_DESKTOP')
-        if desktop.split(':')[-1] in ['Unity', 'MATE', 'GNOME'] \
-          and desktop.split(':')[0] != 'GNOME-Flashback' \
+        if not desktop:
+            return None
+        found = None
+        for val in desktop.split(':'):
+            if val in ['Unity', 'MATE', 'GNOME']:
+                found = True
+                break
+        if found and desktop.split(':')[0] != 'GNOME-Flashback' \
           or locale.getlocale(locale.LC_CTYPE)[0][:3] in ['zh_', 'ja_', 'ko_', 'vi_']:
             system_default = autoConfig
         else:
-            system_default = 'xim'
+            system_default = 'none'
         if systemConfig == 'default':
             system_conf = system_default
         elif os.path.exists('/etc/X11/xinit/xinputrc'):
